# 📰 Treestamps News

## v0.3.4

- Dev

  - Update dependencies.

## v0.3.3

- Features

  - Update dependencies & poetry lockfile

## v0.3.2

- Features

  - Update dependencies & poetry lockfile

## v0.3.1

- Fix

  - Fix factory passed strings instead of paths crash.

## v0.3.0

- Fix

  - Fix factory consuming child timestamps when given files not directories.
  - Fix loading and dumping timestamps not related to the treestamp dir.

- Features

  - Ignore symlinks option.

## v0.2.1

- Fix

  - Support ignore in factory

## v0.2.0

- Features

  - Support ignore globs

## v0.1.3

- Fixes

  - Protect final dump yaml from child cleanup task.

## v0.1.2

- Features

  - colored output.

- Fixes

  - Trap more errors when reading timestamps

## v0.1.1

- Fixes

  - Fix strings submitted to factory instead of paths

## v0.1.0

_First Release_

- Picopt's new timestamper abstracted to a library
